package com.jobs.consumer.config;

import com.netflix.loadbalancer.IRule;
import com.netflix.loadbalancer.RandomRule;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class LoadBalanceRule {

    @Bean
    public IRule rule(){
        /*
            需要注意：SpringCloud 在 2010.0.1 版本之前，集成了 Ribbon。
            在 2010.0.1 版本之后，使用 LoadBalance 替代了 Ribbon。

            当前使用的 SpringCloud 版本为 Hoxton.SR12 ，可以使用 Ribbon。

            Ribbon 提供了 10 种客户端负载均衡策略，
            如果不配置的话，默认采用轮询策略

            常用的有 7 种，如下所示：
            随机 ：RandomRule
            轮询 ：RoundRobinRule
            最小并发：BestAvailableRule
            可用性过滤：AvailabilityFilteringRule
            最小响应时间：WeightedResponseTimeRule
            失败后轮询重试：RetryRule
            性能可用性：ZoneAvoidanceRule
         */

        return new RandomRule();
    }
}
